@@ -1,32 +1,4 @@
 # coding: utf-8
-# /*##########################################################################
-#
-# Copyright (c) 2016-2022 European Synchrotron Radiation Facility
-#
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in
-# all copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
-# THE SOFTWARE.
-#
-# ###########################################################################*/
-
-__authors__ = ["H. Payno"]
-__license__ = "MIT"
-__date__ = "10/01/2022"
-
 
 import os
 from urllib.parse import ParseResult, urlparse
@@ -42,6 +14,8 @@ from tomoscan.identifier import ScanIdentifier, VolumeIdentifier
 from tomoscan.utils import docstring
 from tomoscan.utils.io import deprecated_warning
 
+__all__ = ["NXtomoScanIdentifier", "HDF5VolumeIdentifier", "HDF5TomoScanIdentifier"]
+
 
 class _HDF5IdentifierMixIn:
     def __init__(self, object, hdf5_file, entry, tomo_type):
