@@ -142,7 +142,7 @@ class MockNXtomo(ScanMock):
     """
     Mock an acquisition in a hdf5 file.
 
-    note: for now the Mock class only manage one initial flat and one final
+    .. note:: for now the Mock class only manage one initial flat and one final
     """
 
     _PROJ_COUNT = 1
@@ -197,6 +197,17 @@ class MockNXtomo(ScanMock):
         :param n_refs: number of refs per series
         :param distance: if not None then will save energy on the dataset
         :param energy: if not None then will save the distance on the dataset
+        :param x_pos: position along x axis (according to the NXtomo coordinate system)
+
+                         Z axis
+                                ^    Y axis
+                                | /
+              x-ray             |/
+              -------->          ------> X axis
+
+
+        :param y_pos: position along x axis (according to the NXtomo coordinate system)
+        :param z_pos: position along x axis (according to the NXtomo coordinate system)
         """
         if create_ini_ref is False:
             _logger.warning("create_ini_ref is deprecated. Please use create_init_flat")
