@@ -1,4 +1,4 @@
-from silx.utils.deprecation import deprecated_warning
+from tomoscan.utils.io import deprecated_warning
 
 deprecated_warning(
     "Module",
