@@ -274,6 +274,7 @@ class MultiTIFFVolume(VolumeBase):
             raise ValueError(
                 "Cannot get data_url. An url should be provided. Don't know where to save this."
             )
+        os.makedirs(os.path.dirname(url.file_path()), exist_ok=True)
 
         if url.scheme() == "tifffile":
             if url.data_path() is not None:
@@ -327,6 +328,7 @@ class MultiTIFFVolume(VolumeBase):
                     raise ValueError(f"Scheme {self.url.scheme()} is not handled")
 
         data_url = data_url or self.data_url
+        os.makedirs(os.path.dirname(data_url.file_path()), exist_ok=True)
 
         for i_frame in range(n_frames):
             yield _FrameDumper(data_url, append=self.append if i_frame == 0 else True)
