@@ -1,10 +1,12 @@
-from silx.utils.deprecation import deprecated_warning
+"""deprecated module. Use 'factory' instead"""
+
+from tomoscan.utils.io import deprecated_warning
 
 deprecated_warning(
     "Class",
     name="tomoscan.scanfactory.ScanFactory",
     reason="Has been moved",
-    replacement="tomoscan.factory.TomoObjectFactory",
+    replacement="tomoscan.factory.Factory",
     only_once=True,
 )
 from tomoscan.factory import Factory as ScanFactory  # noqa F401
