@@ -5,7 +5,6 @@ import os
 import io
 from contextlib import contextmanager
 
-
 depreclog = logging.getLogger("tomoscan.DEPRECATION")
 
 deprecache = set([])
@@ -112,7 +111,7 @@ def filter_esrf_mounting_points(path: str):
     """
     parts = path.split(os.sep)
     if len(parts) > 4:
-        if parts[0] == "" and parts[1] in ("gpfs", "mnt") and parts[3] == "data":
+        if parts[0] == "" and parts[1] in ("gpfs", "mnt"):
             new_parts = list(parts[0:1]) + list(parts[3:])
             path = os.sep.join(new_parts)
     return path
